@@ -1,9 +1,9 @@
 #!/bin/sh
 export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
 echo 'name: wai-extra
-version: 3.0.14.1
-id: wai-extra-3.0.14.1-66e8055b51d984feb43fefdbcd17f927
-key: waiex_ETHp0AagaZY8Q4kpUIOhpj
+version: 3.0.15.1
+id: wai-extra-3.0.15.1-954bd1f4cbd0dadcc30817e6afe9d17a
+key: waiex_25rno0j1wK3JwuVadfOIHi
 license: MIT
 maintainer: michael@snoyman.com
 stability: Stable
@@ -93,41 +93,41 @@ exposed-modules:
     Network.Wai.EventSource.EventStream
 hidden-modules: Network.Wai.Middleware.RequestLogger.Internal
 trusted: False
-import-dirs: /usr/lib/ghc-7.10.3/site-local/wai-extra-3.0.14.1
-library-dirs: /usr/lib/ghc-7.10.3/site-local/wai-extra-3.0.14.1
-data-dir: /usr/share/arm-linux-ghc-7.10.3/wai-extra-3.0.14.1
-hs-libraries: HSwai-extra-3.0.14.1-ETHp0AagaZY8Q4kpUIOhpj
+import-dirs: /usr/lib/ghc-7.10.3/site-local/wai-extra-3.0.15.1
+library-dirs: /usr/lib/ghc-7.10.3/site-local/wai-extra-3.0.15.1
+data-dir: /usr/share/arm-linux-ghc-7.10.3/wai-extra-3.0.15.1
+hs-libraries: HSwai-extra-3.0.15.1-25rno0j1wK3JwuVadfOIHi
 depends:
-    aeson-0.11.1.1-0413068b3d94ca1008e286bfe7fa084f
+    aeson-0.11.2.0-296caa0c9ed52dbc363a5964bf5cee68
     ansi-terminal-0.6.2.3-7b40b18f4e53e6f53c2ffd807e929ca9
     base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
     base64-bytestring-1.0.0.1-7819850819049320f81b6417431cc8a5
-    blaze-builder-0.4.0.1-3daa45cd3be9618b289586d273c59e36
+    blaze-builder-0.4.0.2-290873936811c5be5456133d1e8642df
     bytestring-0.10.6.0-3b51e35daa3fe2a56ecd3687fb389cdc
-    case-insensitive-1.2.0.5-6669cd7a393ccedc4f66c0a01b6f0e2f
+    case-insensitive-1.2.0.6-f940e4aded76d28f250fda2e1500b30b
     containers-0.5.6.2-169e53288f333dd2f0207994fd53822f
-    cookie-0.4.1.6-8a746b417cee9e54ae77a0b2d5e8515e
+    cookie-0.4.2-28e8510d867302127f61174b072159ee
     data-default-class-0.0.1-fcbab95490d730dd2489b628499587cd
     deepseq-1.4.1.1-3975618f889b45239daa47b7443eaeee
     directory-1.2.2.0-17b2023f9d7e8036d19e6b52b4f75c98
-    fast-logger-2.4.1-72875ca91290e61690089a3e7f5d8466
-    http-types-0.9-d392878af9c5e1b1993961dc71a9e177
+    fast-logger-2.4.6-432abdc0f5b043114ea69b7c4625cae5
+    http-types-0.9-abc209b9e91b870b477d7ec7669b4ae8
     iproute-1.7.0-38a0b7111fde75b34af10d9c12292092
-    lifted-base-0.2.3.6-26b5b3c50c56a653ba3c5b8bce492107
+    lifted-base-0.2.3.6-9c13caa8bbd360a88b87891885feeeff
     network-2.6.2.1-602ee4a12c5a174f6683a75303a065d3
     old-locale-1.0.0.7-5aedb410aa2e5fddd3c57e9b4de1f46a
-    resourcet-1.1.7.3-3e7ca03abacc332d28328c69bbd74cd4
-    streaming-commons-0.1.15.2-092d722155f2dc7f0b2e7a0dc037f30c
+    resourcet-1.1.7.4-51f149abafdcf0369a30d929df00de54
+    streaming-commons-0.1.15.5-b71913214a53247591329436a8fa2523
     stringsearch-0.3.6.6-bd5f901f10569d353c3dabbb227e877c
-    text-1.2.2.0-2f82ea4adfdd656d9a8840ad2ee17cc0
+    text-1.2.2.1-18afbfeccf88d72c4b6e468c86d2b77d
     time-1.5.0.1-cf94b0d806e26f6c4e356671290061b2
     transformers-0.4.2.0-252429dba576bc247c1932da496e0a3f
     unix-2.7.1.0-a583968f8d5891c6bf334fddb26b19a6
     unix-compat-0.4.1.4-baa19ce04d0e8a47661438a80ea2aec8
-    vault-0.3.0.6-8b1ddbd07c6eb1be1ee9aee781649e3c
-    void-0.7.1-5ad9ec6793ffb57ac26a200023a4290d
-    wai-3.2.0-61d8ab991e10dd6c5057d0dabf632d2a
-    wai-logger-2.2.4.1-f24597f93ba49a0bbd4e6ed0edc7bef2
+    vault-0.3.0.6-2c2444df5306907b16aaa509d25c29c9
+    void-0.7.1-255c5771d2d826ed3cb8a752061ff594
+    wai-3.2.1-82fcd8afd3d66bf63829f2c0f9ec2308
+    wai-logger-2.2.7-be4dfe43e81d159502c14b31210da2fe
     word8-0.1.2-9a296ac80618be494d93f29b398e749d
     zlib-0.6.1.1-863f5ed4c9ef7e591295c362d5c5d2a5
 haddock-interfaces: /usr/share/doc/haskell-wai-extra/html/wai-extra.haddock
